@@ -1,6 +1,7 @@
 import chalk from "chalk";
 import pg from 'pg';
 import { debugLog, logger } from '../../utils/logger.js';
+import { getVarVal } from '../../configuration.js';
 
 const { Pool } = pg;
 
@@ -15,26 +16,26 @@ class DatabaseManager {
       return this.pool;
     }
 
-    // 환경 변수 로깅
-    // logger.debug(chalk.cyan("데이터베이스 연결 설정:"));
-    // logger.debug(
-    //   chalk.cyan(`- 호스트: ${process.env.POSTGRES_HOST || "localhost"}`)
-    // );
-    // logger.debug(chalk.cyan(`- 포트: ${process.env.POSTGRES_PORT || "5433"}`));
-    // logger.debug(
-    //   chalk.cyan(`- 데이터베이스: ${process.env.POSTGRES_DB || "airun"}`)
-    // );
-    // logger.debug(chalk.cyan(`- 사용자: ${process.env.POSTGRES_USER || "ivs"}`));
+    // 중앙화된 설정에서 DB 연결 정보 가져오기
+    const dbHost = await getVarVal('DB_HOST') || 'localhost';
+    const dbPort = parseInt(await getVarVal('DB_PORT') || '5433');
+    const dbUser = await getVarVal('DB_USER') || 'ivs';
+    const dbPassword = await getVarVal('DB_PASSWORD') || '1234';
+    const dbName = await getVarVal('DB_NAME') || 'airun';
 
-    const dbName = process.env.POSTGRES_DB || "airun";
+    // logger.debug(chalk.cyan("데이터베이스 연결 설정 (중앙화된 설정):"));
+    // logger.debug(chalk.cyan(`- 호스트: ${dbHost}`));
+    // logger.debug(chalk.cyan(`- 포트: ${dbPort}`));
+    // logger.debug(chalk.cyan(`- 데이터베이스: ${dbName}`));
+    // logger.debug(chalk.cyan(`- 사용자: ${dbUser}`));
 
     // 1. postgres 기본 DB로 연결해서 존재 여부 체크
     const adminPool = new Pool({
-      user: process.env.POSTGRES_USER || "ivs",
-      host: process.env.POSTGRES_HOST || "localhost",
+      user: dbUser,
+      host: dbHost,
       database: "postgres",
-      password: process.env.POSTGRES_PASSWORD || "1234",
-      port: parseInt(process.env.POSTGRES_PORT || "5433"),
+      password: dbPassword,
+      port: dbPort,
     });
 
     try {
@@ -68,16 +69,16 @@ class DatabaseManager {
       await adminPool.end();
     }
 
-    // 2. airun 데이터베이스에 Pool 연결 (환경변수 기반 설정)
-    const maxConnections = parseInt(process.env.DB_POOL_MAX_SIZE || "20");
-    const minConnections = parseInt(process.env.DB_POOL_MIN_SIZE || "2");
+    // 2. airun 데이터베이스에 Pool 연결 (중앙화된 설정 사용)
+    const maxConnections = parseInt(await getVarVal('DB_POOL_MAX_SIZE') || "20");
+    const minConnections = parseInt(await getVarVal('DB_POOL_MIN_SIZE') || "2");
 
     this.pool = new Pool({
-      user: process.env.POSTGRES_USER || "ivs",
-      host: process.env.POSTGRES_HOST || "localhost",
+      user: dbUser,
+      host: dbHost,
       database: dbName,
-      password: process.env.POSTGRES_PASSWORD || "1234",
-      port: parseInt(process.env.POSTGRES_PORT || "5433"),
+      password: dbPassword,
+      port: dbPort,
       max: maxConnections,            // 환경변수 기반 최대 연결 수
       min: minConnections,            // 환경변수 기반 최소 연결 수
       idleTimeoutMillis: 300000,      // 5분으로 연장 (유휴 연결 관리)
