@@ -419,10 +419,51 @@ export default function Header() {
   };
 
       return (
+    <>
+    <style dangerouslySetInnerHTML={{
+      __html: `
+        /* Chromium-compatible header layout */
+        .header-container {
+          display: grid !important;
+          grid-template-columns: 1fr auto !important;
+          grid-gap: 1rem !important;
+          align-items: center !important;
+          width: 100% !important;
+        }
+        .header-left {
+          display: flex !important;
+          align-items: center !important;
+          min-width: 0 !important;
+          overflow: hidden !important;
+        }
+        .header-right {
+          display: flex !important;
+          align-items: center !important;
+          white-space: nowrap !important;
+          flex-shrink: 0 !important;
+        }
+
+        /* Fallback for older browsers */
+        @supports not (display: grid) {
+          .header-container {
+            display: flex !important;
+            justify-content: space-between !important;
+          }
+          .header-left {
+            flex: 1 !important;
+            max-width: calc(100% - 200px) !important;
+          }
+          .header-right {
+            width: 200px !important;
+            flex-shrink: 0 !important;
+          }
+        }
+      `
+    }} />
     <header className="border-b border-gray-200 dark:border-gray-700 w-full" style={{ backgroundColor: 'var(--header-bg)' }}>
-      <div className="flex items-center w-full p-4 pb-4">
+      <div className="header-container p-4 pb-4">
         {/* 왼쪽: 로고 + 네비 */}
-        <div className="flex items-center gap-2 md:gap-8">
+        <div className="header-left gap-2 md:gap-8">
           <Link href="/" className="flex items-center space-x-3 rtl:space-x-reverse">
             {customLogo ? (
               <div className="flex items-center justify-center">
@@ -448,7 +489,8 @@ export default function Header() {
             )}         
           </Link>
           
-          <nav className="hidden md:flex items-center space-x-1 pl-8">
+          {/* 데스크톱 네비게이션 */}
+          <nav className="hidden lg:flex items-center space-x-0 pl-4 overflow-hidden flex-1 min-w-0 max-w-none">
             {/* 일반 사용자 메뉴 */}
             {isClient && userNavigationItems.map((item) => {
               const isActive = section === item.section || (item.path === '/' && section === 'home');
@@ -457,13 +499,13 @@ export default function Header() {
                 <Link
                   key={item.path}
                   href={item.path}
-                  className={`flex flex-col items-center justify-center px-3 py-2 rounded-xl transition-all duration-200 min-w-[80px] ${
+                  className={`flex flex-col items-center justify-center px-1 py-1 rounded-xl transition-all duration-200 min-w-[70px] ${
                     isActive
                       ? 'bg-blue-100 dark:bg-blue-900/50 text-blue-700 dark:text-blue-300 shadow-md'
                       : 'text-gray-600 dark:text-gray-300 hover:bg-gray-100 dark:hover:bg-gray-700 hover:text-gray-900 dark:hover:text-white hover:shadow-md'
                   }`}
                 >
-                  <IconComponent className="w-8 h-8 mb-2" />
+                  <IconComponent className="w-7 h-7 mb-2" />
                   <span className="text-base font-medium text-center leading-tight">{item.name}</span>
                 </Link>
               );
@@ -479,14 +521,14 @@ export default function Header() {
                     <Link
                       key={item.path}
                       href={item.path}
-                      className={`flex flex-col items-center justify-center px-3 py-2 rounded-xl transition-all duration-200 min-w-[80px] ${
+                      className={`flex flex-col items-center justify-center px-1 py-1 rounded-xl transition-all duration-200 min-w-[70px] ${
                         isActive
                           ? 'bg-purple-100 dark:bg-purple-900/50 text-purple-700 dark:text-purple-300 shadow-md'
                           : 'text-gray-600 dark:text-gray-300 hover:bg-purple-50 dark:hover:bg-purple-900/20 hover:text-purple-700 dark:hover:text-purple-300 hover:shadow-md'
                       }`}
                       title={t('header.adminOnly', 'Admin Only')}
                     >
-                      <IconComponent className="w-8 h-8 mb-2" />
+                      <IconComponent className="w-7 h-7 mb-2" />
                       <span className="text-base font-medium text-center leading-tight">{item.name}</span>
                     </Link>
                   );
@@ -505,7 +547,7 @@ export default function Header() {
                     <Link
                       key={item.path}
                       href={item.path}
-                      className={`flex flex-col items-center justify-center px-3 py-2 rounded-xl transition-all duration-200 min-w-[80px] ${
+                      className={`flex flex-col items-center justify-center px-2 py-2 rounded-xl transition-all duration-200 min-w-[70px] ${
                         isActive
                           ? 'bg-red-100 dark:bg-red-900/50 text-red-700 dark:text-red-300 shadow-md'
                           : 'text-gray-600 dark:text-gray-300 hover:bg-red-50 dark:hover:bg-red-900/20 hover:text-red-700 dark:hover:text-red-300 hover:shadow-md'
@@ -531,7 +573,7 @@ export default function Header() {
                     <Link
                       key={item.path}
                       href={item.path}
-                      className={`flex flex-col items-center justify-center px-3 py-2 rounded-xl transition-all duration-200 min-w-[80px] ${
+                      className={`flex flex-col items-center justify-center px-2 py-2 rounded-xl transition-all duration-200 min-w-[70px] ${
                         isActive
                           ? 'bg-orange-100 dark:bg-orange-900/50 text-orange-700 dark:text-orange-300 shadow-md'
                           : 'text-gray-600 dark:text-gray-300 hover:bg-orange-50 dark:hover:bg-orange-900/20 hover:text-orange-700 dark:hover:text-orange-300 hover:shadow-md'
@@ -546,9 +588,32 @@ export default function Header() {
               </>
             )}
           </nav>
+
+          {/* 중간 크기 화면용 축약된 네비게이션 */}
+          <nav className="hidden md:flex lg:hidden items-center space-x-1 pl-4 overflow-hidden flex-1 min-w-0">
+            {/* 핵심 메뉴만 표시 */}
+            {isClient && userNavigationItems.slice(0, 3).map((item) => {
+              const isActive = section === item.section || (item.path === '/' && section === 'home');
+              const IconComponent = item.icon;
+              return (
+                <Link
+                  key={item.path}
+                  href={item.path}
+                  className={`flex items-center justify-center p-2 rounded-lg transition-all duration-200 min-w-[40px] ${
+                    isActive
+                      ? 'bg-blue-100 dark:bg-blue-900/50 text-blue-700 dark:text-blue-300'
+                      : 'text-gray-600 dark:text-gray-300 hover:bg-gray-100 dark:hover:bg-gray-700 hover:text-gray-900 dark:hover:text-white'
+                  }`}
+                  title={item.name}
+                >
+                  <IconComponent className="w-5 h-5" />
+                </Link>
+              );
+            })}
+          </nav>
         </div>
         {/* 오른쪽: 유저/로그인/테마 */}
-        <div className="flex items-center gap-3 ml-auto">
+        <div className="header-right gap-3">
           {/* 모바일 메뉴 버튼 */}
           <button
             onClick={() => setIsMobileMenuOpen(!isMobileMenuOpen)}
@@ -738,5 +803,6 @@ export default function Header() {
         </div>
       )}
     </header>
+    </>
   );
 } 
\ No newline at end of file
